import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../APIGatewayClient";
import { CreateRequestValidatorRequest, RequestValidator } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link CreateRequestValidatorCommand}.
 */
export interface CreateRequestValidatorCommandInput extends CreateRequestValidatorRequest {
}
/**
 * @public
 *
 * The output of {@link CreateRequestValidatorCommand}.
 */
export interface CreateRequestValidatorCommandOutput extends RequestValidator, __MetadataBearer {
}
declare const CreateRequestValidatorCommand_base: {
    new (input: CreateRequestValidatorCommandInput): import("@smithy/smithy-client").CommandImpl<CreateRequestValidatorCommandInput, CreateRequestValidatorCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: CreateRequestValidatorCommandInput): import("@smithy/smithy-client").CommandImpl<CreateRequestValidatorCommandInput, CreateRequestValidatorCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Creates a RequestValidator of a given RestApi.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { APIGatewayClient, CreateRequestValidatorCommand } from "@aws-sdk/client-api-gateway"; // ES Modules import
 * // const { APIGatewayClient, CreateRequestValidatorCommand } = require("@aws-sdk/client-api-gateway"); // CommonJS import
 * const client = new APIGatewayClient(config);
 * const input = { // CreateRequestValidatorRequest
 *   restApiId: "STRING_VALUE", // required
 *   name: "STRING_VALUE",
 *   validateRequestBody: true || false,
 *   validateRequestParameters: true || false,
 * };
 * const command = new CreateRequestValidatorCommand(input);
 * const response = await client.send(command);
 * // { // RequestValidator
 * //   id: "STRING_VALUE",
 * //   name: "STRING_VALUE",
 * //   validateRequestBody: true || false,
 * //   validateRequestParameters: true || false,
 * // };
 *
 * ```
 *
 * @param CreateRequestValidatorCommandInput - {@link CreateRequestValidatorCommandInput}
 * @returns {@link CreateRequestValidatorCommandOutput}
 * @see {@link CreateRequestValidatorCommandInput} for command's `input` shape.
 * @see {@link CreateRequestValidatorCommandOutput} for command's `response` shape.
 * @see {@link APIGatewayClientResolvedConfig | config} for APIGatewayClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The submitted request is not valid, for example, the input is incomplete or incorrect. See the accompanying error message for details.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>The request configuration has conflicts. For details, see the accompanying error message.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>The request exceeded the rate limit. Retry after the specified time period.</p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>The requested resource is not found. Make sure that the request URI is correct.</p>
 *
 * @throws {@link TooManyRequestsException} (client fault)
 *  <p>The request has reached its throttling limit. Retry after the specified time period.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>The request is denied because the caller has insufficient permissions.</p>
 *
 * @throws {@link APIGatewayServiceException}
 * <p>Base exception class for all service exceptions from APIGateway service.</p>
 *
 *
 * @public
 */
export declare class CreateRequestValidatorCommand extends CreateRequestValidatorCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: CreateRequestValidatorRequest;
            output: RequestValidator;
        };
        sdk: {
            input: CreateRequestValidatorCommandInput;
            output: CreateRequestValidatorCommandOutput;
        };
    };
}
