import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../APIGatewayClient";
import { GetMethodResponseRequest, MethodResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetMethodResponseCommand}.
 */
export interface GetMethodResponseCommandInput extends GetMethodResponseRequest {
}
/**
 * @public
 *
 * The output of {@link GetMethodResponseCommand}.
 */
export interface GetMethodResponseCommandOutput extends MethodResponse, __MetadataBearer {
}
declare const GetMethodResponseCommand_base: {
    new (input: GetMethodResponseCommandInput): import("@smithy/smithy-client").CommandImpl<GetMethodResponseCommandInput, GetMethodResponseCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: GetMethodResponseCommandInput): import("@smithy/smithy-client").CommandImpl<GetMethodResponseCommandInput, GetMethodResponseCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes a MethodResponse resource.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { APIGatewayClient, GetMethodResponseCommand } from "@aws-sdk/client-api-gateway"; // ES Modules import
 * // const { APIGatewayClient, GetMethodResponseCommand } = require("@aws-sdk/client-api-gateway"); // CommonJS import
 * const client = new APIGatewayClient(config);
 * const input = { // GetMethodResponseRequest
 *   restApiId: "STRING_VALUE", // required
 *   resourceId: "STRING_VALUE", // required
 *   httpMethod: "STRING_VALUE", // required
 *   statusCode: "STRING_VALUE", // required
 * };
 * const command = new GetMethodResponseCommand(input);
 * const response = await client.send(command);
 * // { // MethodResponse
 * //   statusCode: "STRING_VALUE",
 * //   responseParameters: { // MapOfStringToBoolean
 * //     "<keys>": true || false,
 * //   },
 * //   responseModels: { // MapOfStringToString
 * //     "<keys>": "STRING_VALUE",
 * //   },
 * // };
 *
 * ```
 *
 * @param GetMethodResponseCommandInput - {@link GetMethodResponseCommandInput}
 * @returns {@link GetMethodResponseCommandOutput}
 * @see {@link GetMethodResponseCommandInput} for command's `input` shape.
 * @see {@link GetMethodResponseCommandOutput} for command's `response` shape.
 * @see {@link APIGatewayClientResolvedConfig | config} for APIGatewayClient's `config` shape.
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>The requested resource is not found. Make sure that the request URI is correct.</p>
 *
 * @throws {@link TooManyRequestsException} (client fault)
 *  <p>The request has reached its throttling limit. Retry after the specified time period.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>The request is denied because the caller has insufficient permissions.</p>
 *
 * @throws {@link APIGatewayServiceException}
 * <p>Base exception class for all service exceptions from APIGateway service.</p>
 *
 *
 * @public
 */
export declare class GetMethodResponseCommand extends GetMethodResponseCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetMethodResponseRequest;
            output: MethodResponse;
        };
        sdk: {
            input: GetMethodResponseCommandInput;
            output: GetMethodResponseCommandOutput;
        };
    };
}
