import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../APIGatewayClient";
import { GetSdkTypesRequest, SdkTypes } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetSdkTypesCommand}.
 */
export interface GetSdkTypesCommandInput extends GetSdkTypesRequest {
}
/**
 * @public
 *
 * The output of {@link GetSdkTypesCommand}.
 */
export interface GetSdkTypesCommandOutput extends SdkTypes, __MetadataBearer {
}
declare const GetSdkTypesCommand_base: {
    new (input: GetSdkTypesCommandInput): import("@smithy/smithy-client").CommandImpl<GetSdkTypesCommandInput, GetSdkTypesCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [GetSdkTypesCommandInput]): import("@smithy/smithy-client").CommandImpl<GetSdkTypesCommandInput, GetSdkTypesCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets SDK types</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { APIGatewayClient, GetSdkTypesCommand } from "@aws-sdk/client-api-gateway"; // ES Modules import
 * // const { APIGatewayClient, GetSdkTypesCommand } = require("@aws-sdk/client-api-gateway"); // CommonJS import
 * const client = new APIGatewayClient(config);
 * const input = { // GetSdkTypesRequest
 *   position: "STRING_VALUE",
 *   limit: Number("int"),
 * };
 * const command = new GetSdkTypesCommand(input);
 * const response = await client.send(command);
 * // { // SdkTypes
 * //   items: [ // ListOfSdkType
 * //     { // SdkType
 * //       id: "STRING_VALUE",
 * //       friendlyName: "STRING_VALUE",
 * //       description: "STRING_VALUE",
 * //       configurationProperties: [ // ListOfSdkConfigurationProperty
 * //         { // SdkConfigurationProperty
 * //           name: "STRING_VALUE",
 * //           friendlyName: "STRING_VALUE",
 * //           description: "STRING_VALUE",
 * //           required: true || false,
 * //           defaultValue: "STRING_VALUE",
 * //         },
 * //       ],
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param GetSdkTypesCommandInput - {@link GetSdkTypesCommandInput}
 * @returns {@link GetSdkTypesCommandOutput}
 * @see {@link GetSdkTypesCommandInput} for command's `input` shape.
 * @see {@link GetSdkTypesCommandOutput} for command's `response` shape.
 * @see {@link APIGatewayClientResolvedConfig | config} for APIGatewayClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The submitted request is not valid, for example, the input is incomplete or incorrect. See the accompanying error message for details.</p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>The requested resource is not found. Make sure that the request URI is correct.</p>
 *
 * @throws {@link TooManyRequestsException} (client fault)
 *  <p>The request has reached its throttling limit. Retry after the specified time period.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>The request is denied because the caller has insufficient permissions.</p>
 *
 * @throws {@link APIGatewayServiceException}
 * <p>Base exception class for all service exceptions from APIGateway service.</p>
 *
 *
 * @public
 */
export declare class GetSdkTypesCommand extends GetSdkTypesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetSdkTypesRequest;
            output: SdkTypes;
        };
        sdk: {
            input: GetSdkTypesCommandInput;
            output: GetSdkTypesCommandOutput;
        };
    };
}
