import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../APIGatewayClient";
import { ClientCertificate, UpdateClientCertificateRequest } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdateClientCertificateCommand}.
 */
export interface UpdateClientCertificateCommandInput extends UpdateClientCertificateRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateClientCertificateCommand}.
 */
export interface UpdateClientCertificateCommandOutput extends ClientCertificate, __MetadataBearer {
}
declare const UpdateClientCertificateCommand_base: {
    new (input: UpdateClientCertificateCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateClientCertificateCommandInput, UpdateClientCertificateCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: UpdateClientCertificateCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateClientCertificateCommandInput, UpdateClientCertificateCommandOutput, APIGatewayClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Changes information about an ClientCertificate resource.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { APIGatewayClient, UpdateClientCertificateCommand } from "@aws-sdk/client-api-gateway"; // ES Modules import
 * // const { APIGatewayClient, UpdateClientCertificateCommand } = require("@aws-sdk/client-api-gateway"); // CommonJS import
 * const client = new APIGatewayClient(config);
 * const input = { // UpdateClientCertificateRequest
 *   clientCertificateId: "STRING_VALUE", // required
 *   patchOperations: [ // ListOfPatchOperation
 *     { // PatchOperation
 *       op: "add" || "remove" || "replace" || "move" || "copy" || "test",
 *       path: "STRING_VALUE",
 *       value: "STRING_VALUE",
 *       from: "STRING_VALUE",
 *     },
 *   ],
 * };
 * const command = new UpdateClientCertificateCommand(input);
 * const response = await client.send(command);
 * // { // ClientCertificate
 * //   clientCertificateId: "STRING_VALUE",
 * //   description: "STRING_VALUE",
 * //   pemEncodedCertificate: "STRING_VALUE",
 * //   createdDate: new Date("TIMESTAMP"),
 * //   expirationDate: new Date("TIMESTAMP"),
 * //   tags: { // MapOfStringToString
 * //     "<keys>": "STRING_VALUE",
 * //   },
 * // };
 *
 * ```
 *
 * @param UpdateClientCertificateCommandInput - {@link UpdateClientCertificateCommandInput}
 * @returns {@link UpdateClientCertificateCommandOutput}
 * @see {@link UpdateClientCertificateCommandInput} for command's `input` shape.
 * @see {@link UpdateClientCertificateCommandOutput} for command's `response` shape.
 * @see {@link APIGatewayClientResolvedConfig | config} for APIGatewayClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The submitted request is not valid, for example, the input is incomplete or incorrect. See the accompanying error message for details.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>The request configuration has conflicts. For details, see the accompanying error message.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>The request exceeded the rate limit. Retry after the specified time period.</p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>The requested resource is not found. Make sure that the request URI is correct.</p>
 *
 * @throws {@link TooManyRequestsException} (client fault)
 *  <p>The request has reached its throttling limit. Retry after the specified time period.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>The request is denied because the caller has insufficient permissions.</p>
 *
 * @throws {@link APIGatewayServiceException}
 * <p>Base exception class for all service exceptions from APIGateway service.</p>
 *
 *
 * @public
 */
export declare class UpdateClientCertificateCommand extends UpdateClientCertificateCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdateClientCertificateRequest;
            output: ClientCertificate;
        };
        sdk: {
            input: UpdateClientCertificateCommandInput;
            output: UpdateClientCertificateCommandOutput;
        };
    };
}
