import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { APIGatewayServiceException as __BaseException } from "./APIGatewayServiceException";
export declare const AccessAssociationSourceType: {
  readonly VPCE: "VPCE";
};
export type AccessAssociationSourceType =
  (typeof AccessAssociationSourceType)[keyof typeof AccessAssociationSourceType];
export interface AccessLogSettings {
  format?: string | undefined;
  destinationArn?: string | undefined;
}
export interface ThrottleSettings {
  burstLimit?: number | undefined;
  rateLimit?: number | undefined;
}
export interface Account {
  cloudwatchRoleArn?: string | undefined;
  throttleSettings?: ThrottleSettings | undefined;
  features?: string[] | undefined;
  apiKeyVersion?: string | undefined;
}
export interface ApiKey {
  id?: string | undefined;
  value?: string | undefined;
  name?: string | undefined;
  customerId?: string | undefined;
  description?: string | undefined;
  enabled?: boolean | undefined;
  createdDate?: Date | undefined;
  lastUpdatedDate?: Date | undefined;
  stageKeys?: string[] | undefined;
  tags?: Record<string, string> | undefined;
}
export interface ApiKeyIds {
  ids?: string[] | undefined;
  warnings?: string[] | undefined;
}
export interface ApiKeys {
  warnings?: string[] | undefined;
  items?: ApiKey[] | undefined;
  position?: string | undefined;
}
export declare const ApiKeysFormat: {
  readonly csv: "csv";
};
export type ApiKeysFormat = (typeof ApiKeysFormat)[keyof typeof ApiKeysFormat];
export declare const ApiKeySourceType: {
  readonly AUTHORIZER: "AUTHORIZER";
  readonly HEADER: "HEADER";
};
export type ApiKeySourceType =
  (typeof ApiKeySourceType)[keyof typeof ApiKeySourceType];
export interface ApiStage {
  apiId?: string | undefined;
  stage?: string | undefined;
  throttle?: Record<string, ThrottleSettings> | undefined;
}
export declare const AuthorizerType: {
  readonly COGNITO_USER_POOLS: "COGNITO_USER_POOLS";
  readonly REQUEST: "REQUEST";
  readonly TOKEN: "TOKEN";
};
export type AuthorizerType =
  (typeof AuthorizerType)[keyof typeof AuthorizerType];
export interface Authorizer {
  id?: string | undefined;
  name?: string | undefined;
  type?: AuthorizerType | undefined;
  providerARNs?: string[] | undefined;
  authType?: string | undefined;
  authorizerUri?: string | undefined;
  authorizerCredentials?: string | undefined;
  identitySource?: string | undefined;
  identityValidationExpression?: string | undefined;
  authorizerResultTtlInSeconds?: number | undefined;
}
export interface Authorizers {
  items?: Authorizer[] | undefined;
  position?: string | undefined;
}
export declare class BadRequestException extends __BaseException {
  readonly name: "BadRequestException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<BadRequestException, __BaseException>
  );
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface StageKey {
  restApiId?: string | undefined;
  stageName?: string | undefined;
}
export interface CreateApiKeyRequest {
  name?: string | undefined;
  description?: string | undefined;
  enabled?: boolean | undefined;
  generateDistinctId?: boolean | undefined;
  value?: string | undefined;
  stageKeys?: StageKey[] | undefined;
  customerId?: string | undefined;
  tags?: Record<string, string> | undefined;
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  retryAfterSeconds?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class NotFoundException extends __BaseException {
  readonly name: "NotFoundException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<NotFoundException, __BaseException>);
}
export declare class TooManyRequestsException extends __BaseException {
  readonly name: "TooManyRequestsException";
  readonly $fault: "client";
  retryAfterSeconds?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyRequestsException, __BaseException>
  );
}
export declare class UnauthorizedException extends __BaseException {
  readonly name: "UnauthorizedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UnauthorizedException, __BaseException>
  );
}
export interface CreateAuthorizerRequest {
  restApiId: string | undefined;
  name: string | undefined;
  type: AuthorizerType | undefined;
  providerARNs?: string[] | undefined;
  authType?: string | undefined;
  authorizerUri?: string | undefined;
  authorizerCredentials?: string | undefined;
  identitySource?: string | undefined;
  identityValidationExpression?: string | undefined;
  authorizerResultTtlInSeconds?: number | undefined;
}
export interface BasePathMapping {
  basePath?: string | undefined;
  restApiId?: string | undefined;
  stage?: string | undefined;
}
export interface CreateBasePathMappingRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
  basePath?: string | undefined;
  restApiId: string | undefined;
  stage?: string | undefined;
}
export declare const CacheClusterSize: {
  readonly SIZE_0_POINT_5_GB: "0.5";
  readonly SIZE_118_GB: "118";
  readonly SIZE_13_POINT_5_GB: "13.5";
  readonly SIZE_1_POINT_6_GB: "1.6";
  readonly SIZE_237_GB: "237";
  readonly SIZE_28_POINT_4_GB: "28.4";
  readonly SIZE_58_POINT_2_GB: "58.2";
  readonly SIZE_6_POINT_1_GB: "6.1";
};
export type CacheClusterSize =
  (typeof CacheClusterSize)[keyof typeof CacheClusterSize];
export interface DeploymentCanarySettings {
  percentTraffic?: number | undefined;
  stageVariableOverrides?: Record<string, string> | undefined;
  useStageCache?: boolean | undefined;
}
export interface CreateDeploymentRequest {
  restApiId: string | undefined;
  stageName?: string | undefined;
  stageDescription?: string | undefined;
  description?: string | undefined;
  cacheClusterEnabled?: boolean | undefined;
  cacheClusterSize?: CacheClusterSize | undefined;
  variables?: Record<string, string> | undefined;
  canarySettings?: DeploymentCanarySettings | undefined;
  tracingEnabled?: boolean | undefined;
}
export interface MethodSnapshot {
  authorizationType?: string | undefined;
  apiKeyRequired?: boolean | undefined;
}
export interface Deployment {
  id?: string | undefined;
  description?: string | undefined;
  createdDate?: Date | undefined;
  apiSummary?: Record<string, Record<string, MethodSnapshot>> | undefined;
}
export declare class ServiceUnavailableException extends __BaseException {
  readonly name: "ServiceUnavailableException";
  readonly $fault: "server";
  retryAfterSeconds?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ServiceUnavailableException, __BaseException>
  );
}
export declare const DocumentationPartType: {
  readonly API: "API";
  readonly AUTHORIZER: "AUTHORIZER";
  readonly METHOD: "METHOD";
  readonly MODEL: "MODEL";
  readonly PATH_PARAMETER: "PATH_PARAMETER";
  readonly QUERY_PARAMETER: "QUERY_PARAMETER";
  readonly REQUEST_BODY: "REQUEST_BODY";
  readonly REQUEST_HEADER: "REQUEST_HEADER";
  readonly RESOURCE: "RESOURCE";
  readonly RESPONSE: "RESPONSE";
  readonly RESPONSE_BODY: "RESPONSE_BODY";
  readonly RESPONSE_HEADER: "RESPONSE_HEADER";
};
export type DocumentationPartType =
  (typeof DocumentationPartType)[keyof typeof DocumentationPartType];
export interface DocumentationPartLocation {
  type: DocumentationPartType | undefined;
  path?: string | undefined;
  method?: string | undefined;
  statusCode?: string | undefined;
  name?: string | undefined;
}
export interface CreateDocumentationPartRequest {
  restApiId: string | undefined;
  location: DocumentationPartLocation | undefined;
  properties: string | undefined;
}
export interface DocumentationPart {
  id?: string | undefined;
  location?: DocumentationPartLocation | undefined;
  properties?: string | undefined;
}
export interface CreateDocumentationVersionRequest {
  restApiId: string | undefined;
  documentationVersion: string | undefined;
  stageName?: string | undefined;
  description?: string | undefined;
}
export interface DocumentationVersion {
  version?: string | undefined;
  createdDate?: Date | undefined;
  description?: string | undefined;
}
export declare const IpAddressType: {
  readonly dualstack: "dualstack";
  readonly ipv4: "ipv4";
};
export type IpAddressType = (typeof IpAddressType)[keyof typeof IpAddressType];
export declare const EndpointType: {
  readonly EDGE: "EDGE";
  readonly PRIVATE: "PRIVATE";
  readonly REGIONAL: "REGIONAL";
};
export type EndpointType = (typeof EndpointType)[keyof typeof EndpointType];
export interface EndpointConfiguration {
  types?: EndpointType[] | undefined;
  ipAddressType?: IpAddressType | undefined;
  vpcEndpointIds?: string[] | undefined;
}
export interface MutualTlsAuthenticationInput {
  truststoreUri?: string | undefined;
  truststoreVersion?: string | undefined;
}
export declare const SecurityPolicy: {
  readonly TLS_1_0: "TLS_1_0";
  readonly TLS_1_2: "TLS_1_2";
};
export type SecurityPolicy =
  (typeof SecurityPolicy)[keyof typeof SecurityPolicy];
export interface CreateDomainNameRequest {
  domainName: string | undefined;
  certificateName?: string | undefined;
  certificateBody?: string | undefined;
  certificatePrivateKey?: string | undefined;
  certificateChain?: string | undefined;
  certificateArn?: string | undefined;
  regionalCertificateName?: string | undefined;
  regionalCertificateArn?: string | undefined;
  endpointConfiguration?: EndpointConfiguration | undefined;
  tags?: Record<string, string> | undefined;
  securityPolicy?: SecurityPolicy | undefined;
  mutualTlsAuthentication?: MutualTlsAuthenticationInput | undefined;
  ownershipVerificationCertificateArn?: string | undefined;
  policy?: string | undefined;
}
export declare const DomainNameStatus: {
  readonly AVAILABLE: "AVAILABLE";
  readonly PENDING: "PENDING";
  readonly PENDING_CERTIFICATE_REIMPORT: "PENDING_CERTIFICATE_REIMPORT";
  readonly PENDING_OWNERSHIP_VERIFICATION: "PENDING_OWNERSHIP_VERIFICATION";
  readonly UPDATING: "UPDATING";
};
export type DomainNameStatus =
  (typeof DomainNameStatus)[keyof typeof DomainNameStatus];
export interface MutualTlsAuthentication {
  truststoreUri?: string | undefined;
  truststoreVersion?: string | undefined;
  truststoreWarnings?: string[] | undefined;
}
export interface DomainName {
  domainName?: string | undefined;
  domainNameId?: string | undefined;
  domainNameArn?: string | undefined;
  certificateName?: string | undefined;
  certificateArn?: string | undefined;
  certificateUploadDate?: Date | undefined;
  regionalDomainName?: string | undefined;
  regionalHostedZoneId?: string | undefined;
  regionalCertificateName?: string | undefined;
  regionalCertificateArn?: string | undefined;
  distributionDomainName?: string | undefined;
  distributionHostedZoneId?: string | undefined;
  endpointConfiguration?: EndpointConfiguration | undefined;
  domainNameStatus?: DomainNameStatus | undefined;
  domainNameStatusMessage?: string | undefined;
  securityPolicy?: SecurityPolicy | undefined;
  tags?: Record<string, string> | undefined;
  mutualTlsAuthentication?: MutualTlsAuthentication | undefined;
  ownershipVerificationCertificateArn?: string | undefined;
  managementPolicy?: string | undefined;
  policy?: string | undefined;
}
export interface CreateDomainNameAccessAssociationRequest {
  domainNameArn: string | undefined;
  accessAssociationSourceType: AccessAssociationSourceType | undefined;
  accessAssociationSource: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface DomainNameAccessAssociation {
  domainNameAccessAssociationArn?: string | undefined;
  domainNameArn?: string | undefined;
  accessAssociationSourceType?: AccessAssociationSourceType | undefined;
  accessAssociationSource?: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface CreateModelRequest {
  restApiId: string | undefined;
  name: string | undefined;
  description?: string | undefined;
  schema?: string | undefined;
  contentType: string | undefined;
}
export interface Model {
  id?: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  schema?: string | undefined;
  contentType?: string | undefined;
}
export interface CreateRequestValidatorRequest {
  restApiId: string | undefined;
  name?: string | undefined;
  validateRequestBody?: boolean | undefined;
  validateRequestParameters?: boolean | undefined;
}
export interface RequestValidator {
  id?: string | undefined;
  name?: string | undefined;
  validateRequestBody?: boolean | undefined;
  validateRequestParameters?: boolean | undefined;
}
export interface CreateResourceRequest {
  restApiId: string | undefined;
  parentId: string | undefined;
  pathPart: string | undefined;
}
export declare const ConnectionType: {
  readonly INTERNET: "INTERNET";
  readonly VPC_LINK: "VPC_LINK";
};
export type ConnectionType =
  (typeof ConnectionType)[keyof typeof ConnectionType];
export declare const ContentHandlingStrategy: {
  readonly CONVERT_TO_BINARY: "CONVERT_TO_BINARY";
  readonly CONVERT_TO_TEXT: "CONVERT_TO_TEXT";
};
export type ContentHandlingStrategy =
  (typeof ContentHandlingStrategy)[keyof typeof ContentHandlingStrategy];
export interface IntegrationResponse {
  statusCode?: string | undefined;
  selectionPattern?: string | undefined;
  responseParameters?: Record<string, string> | undefined;
  responseTemplates?: Record<string, string> | undefined;
  contentHandling?: ContentHandlingStrategy | undefined;
}
export interface TlsConfig {
  insecureSkipVerification?: boolean | undefined;
}
export declare const IntegrationType: {
  readonly AWS: "AWS";
  readonly AWS_PROXY: "AWS_PROXY";
  readonly HTTP: "HTTP";
  readonly HTTP_PROXY: "HTTP_PROXY";
  readonly MOCK: "MOCK";
};
export type IntegrationType =
  (typeof IntegrationType)[keyof typeof IntegrationType];
export interface Integration {
  type?: IntegrationType | undefined;
  httpMethod?: string | undefined;
  uri?: string | undefined;
  connectionType?: ConnectionType | undefined;
  connectionId?: string | undefined;
  credentials?: string | undefined;
  requestParameters?: Record<string, string> | undefined;
  requestTemplates?: Record<string, string> | undefined;
  passthroughBehavior?: string | undefined;
  contentHandling?: ContentHandlingStrategy | undefined;
  timeoutInMillis?: number | undefined;
  cacheNamespace?: string | undefined;
  cacheKeyParameters?: string[] | undefined;
  integrationResponses?: Record<string, IntegrationResponse> | undefined;
  tlsConfig?: TlsConfig | undefined;
}
export interface MethodResponse {
  statusCode?: string | undefined;
  responseParameters?: Record<string, boolean> | undefined;
  responseModels?: Record<string, string> | undefined;
}
export interface Method {
  httpMethod?: string | undefined;
  authorizationType?: string | undefined;
  authorizerId?: string | undefined;
  apiKeyRequired?: boolean | undefined;
  requestValidatorId?: string | undefined;
  operationName?: string | undefined;
  requestParameters?: Record<string, boolean> | undefined;
  requestModels?: Record<string, string> | undefined;
  methodResponses?: Record<string, MethodResponse> | undefined;
  methodIntegration?: Integration | undefined;
  authorizationScopes?: string[] | undefined;
}
export interface Resource {
  id?: string | undefined;
  parentId?: string | undefined;
  pathPart?: string | undefined;
  path?: string | undefined;
  resourceMethods?: Record<string, Method> | undefined;
}
export interface CreateRestApiRequest {
  name: string | undefined;
  description?: string | undefined;
  version?: string | undefined;
  cloneFrom?: string | undefined;
  binaryMediaTypes?: string[] | undefined;
  minimumCompressionSize?: number | undefined;
  apiKeySource?: ApiKeySourceType | undefined;
  endpointConfiguration?: EndpointConfiguration | undefined;
  policy?: string | undefined;
  tags?: Record<string, string> | undefined;
  disableExecuteApiEndpoint?: boolean | undefined;
}
export interface RestApi {
  id?: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  createdDate?: Date | undefined;
  version?: string | undefined;
  warnings?: string[] | undefined;
  binaryMediaTypes?: string[] | undefined;
  minimumCompressionSize?: number | undefined;
  apiKeySource?: ApiKeySourceType | undefined;
  endpointConfiguration?: EndpointConfiguration | undefined;
  policy?: string | undefined;
  tags?: Record<string, string> | undefined;
  disableExecuteApiEndpoint?: boolean | undefined;
  rootResourceId?: string | undefined;
}
export interface CanarySettings {
  percentTraffic?: number | undefined;
  deploymentId?: string | undefined;
  stageVariableOverrides?: Record<string, string> | undefined;
  useStageCache?: boolean | undefined;
}
export interface CreateStageRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
  deploymentId: string | undefined;
  description?: string | undefined;
  cacheClusterEnabled?: boolean | undefined;
  cacheClusterSize?: CacheClusterSize | undefined;
  variables?: Record<string, string> | undefined;
  documentationVersion?: string | undefined;
  canarySettings?: CanarySettings | undefined;
  tracingEnabled?: boolean | undefined;
  tags?: Record<string, string> | undefined;
}
export declare const CacheClusterStatus: {
  readonly AVAILABLE: "AVAILABLE";
  readonly CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS";
  readonly DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS";
  readonly FLUSH_IN_PROGRESS: "FLUSH_IN_PROGRESS";
  readonly NOT_AVAILABLE: "NOT_AVAILABLE";
};
export type CacheClusterStatus =
  (typeof CacheClusterStatus)[keyof typeof CacheClusterStatus];
export declare const UnauthorizedCacheControlHeaderStrategy: {
  readonly FAIL_WITH_403: "FAIL_WITH_403";
  readonly SUCCEED_WITHOUT_RESPONSE_HEADER: "SUCCEED_WITHOUT_RESPONSE_HEADER";
  readonly SUCCEED_WITH_RESPONSE_HEADER: "SUCCEED_WITH_RESPONSE_HEADER";
};
export type UnauthorizedCacheControlHeaderStrategy =
  (typeof UnauthorizedCacheControlHeaderStrategy)[keyof typeof UnauthorizedCacheControlHeaderStrategy];
export interface MethodSetting {
  metricsEnabled?: boolean | undefined;
  loggingLevel?: string | undefined;
  dataTraceEnabled?: boolean | undefined;
  throttlingBurstLimit?: number | undefined;
  throttlingRateLimit?: number | undefined;
  cachingEnabled?: boolean | undefined;
  cacheTtlInSeconds?: number | undefined;
  cacheDataEncrypted?: boolean | undefined;
  requireAuthorizationForCacheControl?: boolean | undefined;
  unauthorizedCacheControlHeaderStrategy?:
    | UnauthorizedCacheControlHeaderStrategy
    | undefined;
}
export interface Stage {
  deploymentId?: string | undefined;
  clientCertificateId?: string | undefined;
  stageName?: string | undefined;
  description?: string | undefined;
  cacheClusterEnabled?: boolean | undefined;
  cacheClusterSize?: CacheClusterSize | undefined;
  cacheClusterStatus?: CacheClusterStatus | undefined;
  methodSettings?: Record<string, MethodSetting> | undefined;
  variables?: Record<string, string> | undefined;
  documentationVersion?: string | undefined;
  accessLogSettings?: AccessLogSettings | undefined;
  canarySettings?: CanarySettings | undefined;
  tracingEnabled?: boolean | undefined;
  webAclArn?: string | undefined;
  tags?: Record<string, string> | undefined;
  createdDate?: Date | undefined;
  lastUpdatedDate?: Date | undefined;
}
export declare const QuotaPeriodType: {
  readonly DAY: "DAY";
  readonly MONTH: "MONTH";
  readonly WEEK: "WEEK";
};
export type QuotaPeriodType =
  (typeof QuotaPeriodType)[keyof typeof QuotaPeriodType];
export interface QuotaSettings {
  limit?: number | undefined;
  offset?: number | undefined;
  period?: QuotaPeriodType | undefined;
}
export interface CreateUsagePlanRequest {
  name: string | undefined;
  description?: string | undefined;
  apiStages?: ApiStage[] | undefined;
  throttle?: ThrottleSettings | undefined;
  quota?: QuotaSettings | undefined;
  tags?: Record<string, string> | undefined;
}
export interface UsagePlan {
  id?: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  apiStages?: ApiStage[] | undefined;
  throttle?: ThrottleSettings | undefined;
  quota?: QuotaSettings | undefined;
  productCode?: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface CreateUsagePlanKeyRequest {
  usagePlanId: string | undefined;
  keyId: string | undefined;
  keyType: string | undefined;
}
export interface UsagePlanKey {
  id?: string | undefined;
  type?: string | undefined;
  value?: string | undefined;
  name?: string | undefined;
}
export interface CreateVpcLinkRequest {
  name: string | undefined;
  description?: string | undefined;
  targetArns: string[] | undefined;
  tags?: Record<string, string> | undefined;
}
export declare const VpcLinkStatus: {
  readonly AVAILABLE: "AVAILABLE";
  readonly DELETING: "DELETING";
  readonly FAILED: "FAILED";
  readonly PENDING: "PENDING";
};
export type VpcLinkStatus = (typeof VpcLinkStatus)[keyof typeof VpcLinkStatus];
export interface VpcLink {
  id?: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  targetArns?: string[] | undefined;
  status?: VpcLinkStatus | undefined;
  statusMessage?: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface DeleteApiKeyRequest {
  apiKey: string | undefined;
}
export interface DeleteAuthorizerRequest {
  restApiId: string | undefined;
  authorizerId: string | undefined;
}
export interface DeleteBasePathMappingRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
  basePath: string | undefined;
}
export interface DeleteClientCertificateRequest {
  clientCertificateId: string | undefined;
}
export interface DeleteDeploymentRequest {
  restApiId: string | undefined;
  deploymentId: string | undefined;
}
export interface DeleteDocumentationPartRequest {
  restApiId: string | undefined;
  documentationPartId: string | undefined;
}
export interface DeleteDocumentationVersionRequest {
  restApiId: string | undefined;
  documentationVersion: string | undefined;
}
export interface DeleteDomainNameRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
}
export interface DeleteDomainNameAccessAssociationRequest {
  domainNameAccessAssociationArn: string | undefined;
}
export declare const GatewayResponseType: {
  readonly ACCESS_DENIED: "ACCESS_DENIED";
  readonly API_CONFIGURATION_ERROR: "API_CONFIGURATION_ERROR";
  readonly AUTHORIZER_CONFIGURATION_ERROR: "AUTHORIZER_CONFIGURATION_ERROR";
  readonly AUTHORIZER_FAILURE: "AUTHORIZER_FAILURE";
  readonly BAD_REQUEST_BODY: "BAD_REQUEST_BODY";
  readonly BAD_REQUEST_PARAMETERS: "BAD_REQUEST_PARAMETERS";
  readonly DEFAULT_4XX: "DEFAULT_4XX";
  readonly DEFAULT_5XX: "DEFAULT_5XX";
  readonly EXPIRED_TOKEN: "EXPIRED_TOKEN";
  readonly INTEGRATION_FAILURE: "INTEGRATION_FAILURE";
  readonly INTEGRATION_TIMEOUT: "INTEGRATION_TIMEOUT";
  readonly INVALID_API_KEY: "INVALID_API_KEY";
  readonly INVALID_SIGNATURE: "INVALID_SIGNATURE";
  readonly MISSING_AUTHENTICATION_TOKEN: "MISSING_AUTHENTICATION_TOKEN";
  readonly QUOTA_EXCEEDED: "QUOTA_EXCEEDED";
  readonly REQUEST_TOO_LARGE: "REQUEST_TOO_LARGE";
  readonly RESOURCE_NOT_FOUND: "RESOURCE_NOT_FOUND";
  readonly THROTTLED: "THROTTLED";
  readonly UNAUTHORIZED: "UNAUTHORIZED";
  readonly UNSUPPORTED_MEDIA_TYPE: "UNSUPPORTED_MEDIA_TYPE";
  readonly WAF_FILTERED: "WAF_FILTERED";
};
export type GatewayResponseType =
  (typeof GatewayResponseType)[keyof typeof GatewayResponseType];
export interface DeleteGatewayResponseRequest {
  restApiId: string | undefined;
  responseType: GatewayResponseType | undefined;
}
export interface DeleteIntegrationRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
}
export interface DeleteIntegrationResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
}
export interface DeleteMethodRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
}
export interface DeleteMethodResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
}
export interface DeleteModelRequest {
  restApiId: string | undefined;
  modelName: string | undefined;
}
export interface DeleteRequestValidatorRequest {
  restApiId: string | undefined;
  requestValidatorId: string | undefined;
}
export interface DeleteResourceRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
}
export interface DeleteRestApiRequest {
  restApiId: string | undefined;
}
export interface DeleteStageRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
}
export interface DeleteUsagePlanRequest {
  usagePlanId: string | undefined;
}
export interface DeleteUsagePlanKeyRequest {
  usagePlanId: string | undefined;
  keyId: string | undefined;
}
export interface DeleteVpcLinkRequest {
  vpcLinkId: string | undefined;
}
export interface FlushStageAuthorizersCacheRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
}
export interface FlushStageCacheRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
}
export interface ClientCertificate {
  clientCertificateId?: string | undefined;
  description?: string | undefined;
  pemEncodedCertificate?: string | undefined;
  createdDate?: Date | undefined;
  expirationDate?: Date | undefined;
  tags?: Record<string, string> | undefined;
}
export interface GenerateClientCertificateRequest {
  description?: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface GetAccountRequest {}
export interface GetApiKeyRequest {
  apiKey: string | undefined;
  includeValue?: boolean | undefined;
}
export interface GetApiKeysRequest {
  position?: string | undefined;
  limit?: number | undefined;
  nameQuery?: string | undefined;
  customerId?: string | undefined;
  includeValues?: boolean | undefined;
}
export interface GetAuthorizerRequest {
  restApiId: string | undefined;
  authorizerId: string | undefined;
}
export interface GetAuthorizersRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface GetBasePathMappingRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
  basePath: string | undefined;
}
export interface BasePathMappings {
  items?: BasePathMapping[] | undefined;
  position?: string | undefined;
}
export interface GetBasePathMappingsRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface GetClientCertificateRequest {
  clientCertificateId: string | undefined;
}
export interface ClientCertificates {
  items?: ClientCertificate[] | undefined;
  position?: string | undefined;
}
export interface GetClientCertificatesRequest {
  position?: string | undefined;
  limit?: number | undefined;
}
export interface GetDeploymentRequest {
  restApiId: string | undefined;
  deploymentId: string | undefined;
  embed?: string[] | undefined;
}
export interface Deployments {
  items?: Deployment[] | undefined;
  position?: string | undefined;
}
export interface GetDeploymentsRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface GetDocumentationPartRequest {
  restApiId: string | undefined;
  documentationPartId: string | undefined;
}
export interface DocumentationParts {
  items?: DocumentationPart[] | undefined;
  position?: string | undefined;
}
export declare const LocationStatusType: {
  readonly DOCUMENTED: "DOCUMENTED";
  readonly UNDOCUMENTED: "UNDOCUMENTED";
};
export type LocationStatusType =
  (typeof LocationStatusType)[keyof typeof LocationStatusType];
export interface GetDocumentationPartsRequest {
  restApiId: string | undefined;
  type?: DocumentationPartType | undefined;
  nameQuery?: string | undefined;
  path?: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
  locationStatus?: LocationStatusType | undefined;
}
export interface GetDocumentationVersionRequest {
  restApiId: string | undefined;
  documentationVersion: string | undefined;
}
export interface DocumentationVersions {
  items?: DocumentationVersion[] | undefined;
  position?: string | undefined;
}
export interface GetDocumentationVersionsRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface GetDomainNameRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
}
export interface DomainNameAccessAssociations {
  items?: DomainNameAccessAssociation[] | undefined;
  position?: string | undefined;
}
export declare const ResourceOwner: {
  readonly OTHER_ACCOUNTS: "OTHER_ACCOUNTS";
  readonly SELF: "SELF";
};
export type ResourceOwner = (typeof ResourceOwner)[keyof typeof ResourceOwner];
export interface GetDomainNameAccessAssociationsRequest {
  position?: string | undefined;
  limit?: number | undefined;
  resourceOwner?: ResourceOwner | undefined;
}
export interface DomainNames {
  items?: DomainName[] | undefined;
  position?: string | undefined;
}
export interface GetDomainNamesRequest {
  position?: string | undefined;
  limit?: number | undefined;
  resourceOwner?: ResourceOwner | undefined;
}
export interface ExportResponse {
  contentType?: string | undefined;
  contentDisposition?: string | undefined;
  body?: Uint8Array | undefined;
}
export interface GetExportRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
  exportType: string | undefined;
  parameters?: Record<string, string> | undefined;
  accepts?: string | undefined;
}
export interface GatewayResponse {
  responseType?: GatewayResponseType | undefined;
  statusCode?: string | undefined;
  responseParameters?: Record<string, string> | undefined;
  responseTemplates?: Record<string, string> | undefined;
  defaultResponse?: boolean | undefined;
}
export interface GetGatewayResponseRequest {
  restApiId: string | undefined;
  responseType: GatewayResponseType | undefined;
}
export interface GatewayResponses {
  items?: GatewayResponse[] | undefined;
  position?: string | undefined;
}
export interface GetGatewayResponsesRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface GetIntegrationRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
}
export interface GetIntegrationResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
}
export interface GetMethodRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
}
export interface GetMethodResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
}
export interface GetModelRequest {
  restApiId: string | undefined;
  modelName: string | undefined;
  flatten?: boolean | undefined;
}
export interface GetModelsRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface Models {
  items?: Model[] | undefined;
  position?: string | undefined;
}
export interface GetModelTemplateRequest {
  restApiId: string | undefined;
  modelName: string | undefined;
}
export interface Template {
  value?: string | undefined;
}
export interface GetRequestValidatorRequest {
  restApiId: string | undefined;
  requestValidatorId: string | undefined;
}
export interface GetRequestValidatorsRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface RequestValidators {
  items?: RequestValidator[] | undefined;
  position?: string | undefined;
}
export interface GetResourceRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  embed?: string[] | undefined;
}
export interface GetResourcesRequest {
  restApiId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
  embed?: string[] | undefined;
}
export interface Resources {
  items?: Resource[] | undefined;
  position?: string | undefined;
}
export interface GetRestApiRequest {
  restApiId: string | undefined;
}
export interface GetRestApisRequest {
  position?: string | undefined;
  limit?: number | undefined;
}
export interface RestApis {
  items?: RestApi[] | undefined;
  position?: string | undefined;
}
export interface GetSdkRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
  sdkType: string | undefined;
  parameters?: Record<string, string> | undefined;
}
export interface SdkResponse {
  contentType?: string | undefined;
  contentDisposition?: string | undefined;
  body?: Uint8Array | undefined;
}
export interface GetSdkTypeRequest {
  id: string | undefined;
}
export interface SdkConfigurationProperty {
  name?: string | undefined;
  friendlyName?: string | undefined;
  description?: string | undefined;
  required?: boolean | undefined;
  defaultValue?: string | undefined;
}
export interface SdkType {
  id?: string | undefined;
  friendlyName?: string | undefined;
  description?: string | undefined;
  configurationProperties?: SdkConfigurationProperty[] | undefined;
}
export interface GetSdkTypesRequest {
  position?: string | undefined;
  limit?: number | undefined;
}
export interface SdkTypes {
  items?: SdkType[] | undefined;
}
export interface GetStageRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
}
export interface GetStagesRequest {
  restApiId: string | undefined;
  deploymentId?: string | undefined;
}
export interface Stages {
  item?: Stage[] | undefined;
}
export interface GetTagsRequest {
  resourceArn: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface Tags {
  tags?: Record<string, string> | undefined;
}
export interface GetUsageRequest {
  usagePlanId: string | undefined;
  keyId?: string | undefined;
  startDate: string | undefined;
  endDate: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
}
export interface Usage {
  usagePlanId?: string | undefined;
  startDate?: string | undefined;
  endDate?: string | undefined;
  items?: Record<string, number[][]> | undefined;
  position?: string | undefined;
}
export interface GetUsagePlanRequest {
  usagePlanId: string | undefined;
}
export interface GetUsagePlanKeyRequest {
  usagePlanId: string | undefined;
  keyId: string | undefined;
}
export interface GetUsagePlanKeysRequest {
  usagePlanId: string | undefined;
  position?: string | undefined;
  limit?: number | undefined;
  nameQuery?: string | undefined;
}
export interface UsagePlanKeys {
  items?: UsagePlanKey[] | undefined;
  position?: string | undefined;
}
export interface GetUsagePlansRequest {
  position?: string | undefined;
  keyId?: string | undefined;
  limit?: number | undefined;
}
export interface UsagePlans {
  items?: UsagePlan[] | undefined;
  position?: string | undefined;
}
export interface GetVpcLinkRequest {
  vpcLinkId: string | undefined;
}
export interface GetVpcLinksRequest {
  position?: string | undefined;
  limit?: number | undefined;
}
export interface VpcLinks {
  items?: VpcLink[] | undefined;
  position?: string | undefined;
}
export interface ImportApiKeysRequest {
  body: Uint8Array | undefined;
  format: ApiKeysFormat | undefined;
  failOnWarnings?: boolean | undefined;
}
export interface DocumentationPartIds {
  ids?: string[] | undefined;
  warnings?: string[] | undefined;
}
export declare const PutMode: {
  readonly Merge: "merge";
  readonly Overwrite: "overwrite";
};
export type PutMode = (typeof PutMode)[keyof typeof PutMode];
export interface ImportDocumentationPartsRequest {
  restApiId: string | undefined;
  mode?: PutMode | undefined;
  failOnWarnings?: boolean | undefined;
  body: Uint8Array | undefined;
}
export interface ImportRestApiRequest {
  failOnWarnings?: boolean | undefined;
  parameters?: Record<string, string> | undefined;
  body: Uint8Array | undefined;
}
export interface PutGatewayResponseRequest {
  restApiId: string | undefined;
  responseType: GatewayResponseType | undefined;
  statusCode?: string | undefined;
  responseParameters?: Record<string, string> | undefined;
  responseTemplates?: Record<string, string> | undefined;
}
export interface PutIntegrationRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  type: IntegrationType | undefined;
  integrationHttpMethod?: string | undefined;
  uri?: string | undefined;
  connectionType?: ConnectionType | undefined;
  connectionId?: string | undefined;
  credentials?: string | undefined;
  requestParameters?: Record<string, string> | undefined;
  requestTemplates?: Record<string, string> | undefined;
  passthroughBehavior?: string | undefined;
  cacheNamespace?: string | undefined;
  cacheKeyParameters?: string[] | undefined;
  contentHandling?: ContentHandlingStrategy | undefined;
  timeoutInMillis?: number | undefined;
  tlsConfig?: TlsConfig | undefined;
}
export interface PutIntegrationResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
  selectionPattern?: string | undefined;
  responseParameters?: Record<string, string> | undefined;
  responseTemplates?: Record<string, string> | undefined;
  contentHandling?: ContentHandlingStrategy | undefined;
}
export interface PutMethodRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  authorizationType: string | undefined;
  authorizerId?: string | undefined;
  apiKeyRequired?: boolean | undefined;
  operationName?: string | undefined;
  requestParameters?: Record<string, boolean> | undefined;
  requestModels?: Record<string, string> | undefined;
  requestValidatorId?: string | undefined;
  authorizationScopes?: string[] | undefined;
}
export interface PutMethodResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
  responseParameters?: Record<string, boolean> | undefined;
  responseModels?: Record<string, string> | undefined;
}
export interface PutRestApiRequest {
  restApiId: string | undefined;
  mode?: PutMode | undefined;
  failOnWarnings?: boolean | undefined;
  parameters?: Record<string, string> | undefined;
  body: Uint8Array | undefined;
}
export interface RejectDomainNameAccessAssociationRequest {
  domainNameAccessAssociationArn: string | undefined;
  domainNameArn: string | undefined;
}
export interface TagResourceRequest {
  resourceArn: string | undefined;
  tags: Record<string, string> | undefined;
}
export interface TestInvokeAuthorizerRequest {
  restApiId: string | undefined;
  authorizerId: string | undefined;
  headers?: Record<string, string> | undefined;
  multiValueHeaders?: Record<string, string[]> | undefined;
  pathWithQueryString?: string | undefined;
  body?: string | undefined;
  stageVariables?: Record<string, string> | undefined;
  additionalContext?: Record<string, string> | undefined;
}
export interface TestInvokeAuthorizerResponse {
  clientStatus?: number | undefined;
  log?: string | undefined;
  latency?: number | undefined;
  principalId?: string | undefined;
  policy?: string | undefined;
  authorization?: Record<string, string[]> | undefined;
  claims?: Record<string, string> | undefined;
}
export interface TestInvokeMethodRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  pathWithQueryString?: string | undefined;
  body?: string | undefined;
  headers?: Record<string, string> | undefined;
  multiValueHeaders?: Record<string, string[]> | undefined;
  clientCertificateId?: string | undefined;
  stageVariables?: Record<string, string> | undefined;
}
export interface TestInvokeMethodResponse {
  status?: number | undefined;
  body?: string | undefined;
  headers?: Record<string, string> | undefined;
  multiValueHeaders?: Record<string, string[]> | undefined;
  log?: string | undefined;
  latency?: number | undefined;
}
export interface UntagResourceRequest {
  resourceArn: string | undefined;
  tagKeys: string[] | undefined;
}
export declare const Op: {
  readonly add: "add";
  readonly copy: "copy";
  readonly move: "move";
  readonly remove: "remove";
  readonly replace: "replace";
  readonly test: "test";
};
export type Op = (typeof Op)[keyof typeof Op];
export interface PatchOperation {
  op?: Op | undefined;
  path?: string | undefined;
  value?: string | undefined;
  from?: string | undefined;
}
export interface UpdateAccountRequest {
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateApiKeyRequest {
  apiKey: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateAuthorizerRequest {
  restApiId: string | undefined;
  authorizerId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateBasePathMappingRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
  basePath: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateClientCertificateRequest {
  clientCertificateId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateDeploymentRequest {
  restApiId: string | undefined;
  deploymentId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateDocumentationPartRequest {
  restApiId: string | undefined;
  documentationPartId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateDocumentationVersionRequest {
  restApiId: string | undefined;
  documentationVersion: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateDomainNameRequest {
  domainName: string | undefined;
  domainNameId?: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateGatewayResponseRequest {
  restApiId: string | undefined;
  responseType: GatewayResponseType | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateIntegrationRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateIntegrationResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateMethodRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateMethodResponseRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  httpMethod: string | undefined;
  statusCode: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateModelRequest {
  restApiId: string | undefined;
  modelName: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateRequestValidatorRequest {
  restApiId: string | undefined;
  requestValidatorId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateResourceRequest {
  restApiId: string | undefined;
  resourceId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateRestApiRequest {
  restApiId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateStageRequest {
  restApiId: string | undefined;
  stageName: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateUsageRequest {
  usagePlanId: string | undefined;
  keyId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateUsagePlanRequest {
  usagePlanId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
export interface UpdateVpcLinkRequest {
  vpcLinkId: string | undefined;
  patchOperations?: PatchOperation[] | undefined;
}
